@@ -10,11 +10,14 @@ Users looking for something as simple to use as libmilter should take a look at
 
 from typing import TYPE_CHECKING
 
+from .core import EditMessage as EditMessage
+from .core import EventMessage as EventMessage
 from .core import FilterProtocol as FilterProtocol
+from .core import ResponseMessage as ResponseMessage
 from .exceptions import *
 from .messages import *
 
 if TYPE_CHECKING:
 	from .buffer import FixedSizeBuffer as FixedSizeBuffer
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
